###########################################################
#                  Find Flann Library
#----------------------------------------------------------

find_path(NANOFLANN_DIR nanoflann.hpp
    HINTS "${NANOFLANN_ROOT}" "$ENV{NANOFLANN_ROOT}" "${NANOFLANN_INCLUDE_DIR_HINTS}"
    PATHS "$ENV{PROGRAMFILES}/nanoflann" "$ENV{PROGRAMW6432}/nanoflann"
    PATH_SUFFIXES nanoflann
    DOC "Root directory of NANOFLANN includes")

##====================================================
## Include NANOFLANN library
##----------------------------------------------------
if(EXISTS "${NANOFLANN_DIR}" AND NOT "${NANOFLANN_DIR}" STREQUAL "")
  set(NANOFLANN_FOUND TRUE)
  set(NANOFLANN_INCLUDE_DIRS ${NANOFLANN_DIR})
  set(NANOFLANN_DIR "${NANOFLANN_DIR}" CACHE PATH "" FORCE)
  MARK_AS_ADVANCED(NANOFLANN_DIR)

  # Extract Flann version from nanoflann.hpp
  set(NANOFLANN_VERSION_FILE ${NANOFLANN_INCLUDE_DIRS}/nanoflann.hpp)
  file(READ ${NANOFLANN_VERSION_FILE} NANOFLANN_VERSION_FILE_CONTENTS)
  string(REGEX MATCH "#define NANOFLANN_VERSION_\\s+0x([0-9]+)"
    NANOFLANN_VERSION "${NANOFLANN_VERSION_FILE_CONTENTS}")
  string(REGEX REPLACE "#define NANOFLANN_VERSION_\\s+0x(\\d)(\\d)(\\d)" "\\1.\\2.\\3"
    NANOFLANN_VERSION "${NANOFLANN_VERSION}")
  set(NANOFLANN_INCLUDE_DIR ${NANOFLANN_DIR})
  add_library(nanoflann INTERFACE IMPORTED GLOBAL)

  message(STATUS "NanoFlann found (include: ${NANOFLANN_INCLUDE_DIRS})")
else()
  message(FATAL_ERROR "You are attempting to build without NanoFlann. "
          "Please use cmake variable -DNANOFLANN_INCLUDE_DIR_HINTS:STRING=\"PATH\" "
          "or NANOFLANN_INCLUDE_DIR_HINTS env. variable to a valid Flann path. ")
  package_report_not_found(NANOFLANN "NanoFlann cannot be found")
endif()
##====================================================
